@@ -24,7 +24,6 @@ class Restriction(object):
         local_alias,
         related_alias,
         predicate,
-        where_class,
     ):
         self.forward = forward
         self.local_model = local_model
@@ -32,7 +31,6 @@ class Restriction(object):
         self.related_alias = related_alias
         self.local_alias = local_alias
         self.predicate = predicate
-        self.where_class = where_class
 
     def as_sql(self, compiler, connection):
         local, related = self.local_alias, self.related_alias
@@ -227,7 +225,7 @@ class CustomForeignObjectRel(ForeignObjectRel):
     def relationship_related_query_name(self):
         return self.remote_field.name
 
-    def get_extra_restriction(self, where_class, alias, related_alias):
+    def _get_extra_restriction(self, alias, related_alias):
         return Restriction(
             forward=False,
             local_model=self.related_model,
@@ -235,9 +233,20 @@ class CustomForeignObjectRel(ForeignObjectRel):
             local_alias=related_alias,
             related_alias=alias,
             predicate=self.field.predicate,
-            where_class=where_class,
         )
 
+    def _get_extra_restriction_legacy(self, where_class, alias, related_alias):
+        # this is a shim to maintain compatibility with django < 4.0
+        return self._get_extra_restriction(alias, related_alias)
+
+    # this is required to handle a change in Django 4.0
+    # https://docs.djangoproject.com/en/4.0/releases/4.0/#miscellaneous
+    # the signature of the (private) funtion was changed
+    if django.VERSION < (4, 0):
+        get_extra_restriction = _get_extra_restriction_legacy
+    else:
+        get_extra_restriction = _get_extra_restriction
+
     @classmethod
     def _resolve_expression_local_references(cls, expr, obj):
         if isinstance(expr, L):
@@ -354,7 +363,7 @@ class Relationship(models.ForeignObject):
     def get_accessor_name(self):
         return self.name
 
-    def get_extra_restriction(self, where_class, related_alias, local_alias):
+    def _get_extra_restriction(self, related_alias, local_alias):
         return Restriction(
             forward=True,
             local_model=self.model,
@@ -362,9 +371,21 @@ class Relationship(models.ForeignObject):
             local_alias=local_alias,
             related_alias=related_alias,
             predicate=self.predicate,
-            where_class=where_class,
         )
 
+    def _get_extra_restriction_legacy(self, where_class, alias, related_alias):
+        # this is a shim to maintain compatibility with django < 4.0
+        return self._get_extra_restriction(alias, related_alias)
+
+    # this is required to handle a change in Django 4.0
+    # https://docs.djangoproject.com/en/4.0/releases/4.0/#miscellaneous
+    # the signature of the (private) funtion was changed
+    if django.VERSION < (4, 0):
+        get_extra_restriction = _get_extra_restriction_legacy
+    else:
+        get_extra_restriction = _get_extra_restriction
+
+
     def get_forward_related_filter(self, obj):
         """
         Return the filter arguments which select the instances of self.model
